@@ -4,6 +4,7 @@ import asyncio
 from collections import defaultdict
 from collections.abc import Awaitable, Callable, Iterator
 from contextlib import contextmanager
+from datetime import datetime
 from functools import partial
 import importlib.resources
 import os
@@ -29,9 +30,8 @@ from instawow import __version__, db, matchers, models
 from instawow import results as R
 from instawow.common import Strategy
 from instawow.config import Config
-from instawow.manager import Manager, TraceRequestCtx, init_web_client
+from instawow.manager import Manager, TraceRequestCtx, init_web_client, is_outdated
 from instawow.resolvers import CatalogueEntry, Defn
-from instawow.utils import is_outdated
 from instawow.utils import run_in_thread as t
 from instawow.utils import uniq
 
@@ -179,7 +179,8 @@ class SearchParams(_ProfileParamMixin, BaseParams):
 
     search_terms: str
     limit: int
-    sources: typing.Optional[typing.Set[str]] = None
+    sources: typing.Set[str]
+    start_date: typing.Optional[datetime]
 
     async def respond(self, managers: _ManagerWorkQueue) -> list[CatalogueEntry]:
         return await managers.run(
@@ -189,6 +190,7 @@ class SearchParams(_ProfileParamMixin, BaseParams):
                 search_terms=self.search_terms,
                 limit=self.limit,
                 sources=self.sources,
+                start_date=self.start_date,
             ),
         )
 
