@@ -3,11 +3,11 @@ from __future__ import annotations
 import asyncio
 from collections.abc import Awaitable, Callable, Generator, Iterable, Iterator, Sequence, Set
 from contextlib import contextmanager
-from datetime import datetime
+from datetime import datetime, timezone
 from enum import Enum
 from functools import partial, wraps
 import importlib.util
-from itertools import chain
+from itertools import chain, repeat
 from pathlib import Path
 import textwrap
 from typing import Any, NoReturn, TypeVar, overload
@@ -22,7 +22,7 @@ from .common import Strategy
 from .config import Config, Flavour, setup_logging
 from .plugins import load_plugins
 from .resolvers import ChangelogFormat, Defn
-from .utils import cached_property, gather, is_outdated, make_progress_bar, tabulate, uniq
+from .utils import StrEnum, cached_property, gather, make_progress_bar, tabulate, uniq
 
 _T = TypeVar('_T')
 _F = TypeVar('_F', bound='Callable[..., object]')
@@ -68,7 +68,7 @@ class Report:
     def generate(self) -> None:
         manager_wrapper: ManagerWrapper | None = click.get_current_context().obj
         if manager_wrapper and manager_wrapper.manager.config.auto_update_check:
-            outdated, new_version = run_with_progress(is_outdated())
+            outdated, new_version = run_with_progress(_manager.is_outdated())
             if outdated:
                 click.echo(f'{self.WARNING_SYMBOL} instawow-{new_version} is available')
 
@@ -339,8 +339,7 @@ _EXCLUDED_STRATEGIES = frozenset({Strategy.default, Strategy.version})
     callback=partial(_combine_addons, parse_into_defn_with_strategy),
     metavar='<STRATEGY ADDON>...',
     help='A strategy followed by an add-on definition.  '
-    'The strategy is one of: '
-    f'{", ".join(s for s in Strategy if s not in _EXCLUDED_STRATEGIES)}.',
+    f'One of: {", ".join(s for s in Strategy if s not in _EXCLUDED_STRATEGIES)}.',
 )
 @click.option(
     '--version',
@@ -428,7 +427,7 @@ def remove(manager: _manager.Manager, addons: Sequence[Defn], keep_folders: bool
 @ManagerWrapper.pass_manager
 def rollback(manager: _manager.Manager, addon: Defn, version: str | None, undo: bool) -> None:
     "Roll an add-on back to an older version."
-    from .prompts import Choice, select
+    from .prompts import Choice, ask, select
 
     if version and undo:
         raise click.UsageError('Cannot use "--version" and "--undo" together')
@@ -462,9 +461,9 @@ def rollback(manager: _manager.Manager, addon: Defn, version: str | None, undo:
             )
             for v in versions
         ]
-        selection = select(
-            f'Select version of {reconstructed_defn.to_urn()} for rollback', choices
-        ).unsafe_ask()
+        selection = ask(
+            select(f'Select version of {reconstructed_defn.to_urn()} for rollback', choices)
+        )
 
     Report(
         run_with_progress(
@@ -490,7 +489,7 @@ def reconcile(manager: _manager.Manager, auto: bool, list_unreconciled: bool) ->
         match_folder_name_subsets,
         match_toc_source_ids,
     )
-    from .prompts import PkgChoice, confirm, select, skip
+    from .prompts import PkgChoice, ask, confirm, select, skip
 
     preamble = textwrap.dedent(
         '''\
@@ -524,8 +523,7 @@ def reconcile(manager: _manager.Manager, auto: bool, list_unreconciled: bool) ->
         highlight_version = len({i.version for i in chain(addons, pkgs)}) > 1
         choices = list(chain(map(construct_choice, pkgs), (skip,)))
         addon = addons[0]
-        # Using 'unsafe_ask' to let ^C bubble up
-        selection = select(f'{addon.name} [{addon.version or "?"}]', choices).unsafe_ask()
+        selection = ask(select(f'{addon.name} [{addon.version or "?"}]', choices))
         return selection
 
     def prompt(groups: Sequence[tuple[list[AddonFolder], list[Defn]]]) -> Iterable[Defn]:
@@ -562,7 +560,7 @@ def reconcile(manager: _manager.Manager, auto: bool, list_unreconciled: bool) ->
     matcher = match_all()
     for _ in matcher:  # Skip over consumer yields
         selections = matcher.send(leftovers)
-        if selections and (auto or confirm('Install selected add-ons?').unsafe_ask()):
+        if selections and (auto or ask(confirm('Install selected add-ons?'))):
             results = run_with_progress(manager.install(selections, replace=True))
             Report(results.items()).generate()
 
@@ -578,6 +576,13 @@ def _concat_search_terms(_: click.Context, __: click.Parameter, value: tuple[str
     return ' '.join(value)
 
 
+def _parse_iso_date_into_datetime(
+    _: click.Context, __: click.Parameter, value: str | None
+) -> datetime | None:
+    if value is not None:
+        return datetime.strptime(value, '%Y-%m-%d').replace(tzinfo=timezone.utc)
+
+
 @main.command()
 @click.argument('search-terms', nargs=-1, required=True, callback=_concat_search_terms)
 @click.option(
@@ -587,6 +592,12 @@ def _concat_search_terms(_: click.Context, __: click.Parameter, value: tuple[str
     type=click.IntRange(1, 20, clamp=True),
     help='A number to limit results to.',
 )
+@click.option(
+    '--start-date',
+    callback=_parse_iso_date_into_datetime,
+    help='Omit results before this date.',
+    metavar='YYYY-MM-DD',
+)
 @click.option(
     '--source',
     'sources',
@@ -594,13 +605,21 @@ def _concat_search_terms(_: click.Context, __: click.Parameter, value: tuple[str
     help='A source to search in.  Repeatable.',
 )
 @click.pass_context
-def search(ctx: click.Context, search_terms: str, limit: int, sources: Sequence[str]) -> None:
+def search(
+    ctx: click.Context,
+    search_terms: str,
+    limit: int,
+    sources: Sequence[str],
+    start_date: datetime | None,
+) -> None:
     "Search for add-ons to install."
-    from .prompts import PkgChoice, checkbox, confirm
+    from .prompts import PkgChoice, ask, checkbox, confirm
 
     manager: _manager.Manager = ctx.obj.manager
 
-    entries = run_with_progress(manager.search(search_terms, limit, frozenset(sources) or None))
+    entries = run_with_progress(
+        manager.search(search_terms, limit, frozenset(sources), start_date)
+    )
     defns = [Defn(e.source, e.id) for e in entries]
     pkgs = (
         (d.with_(alias=r.slug), r)
@@ -609,14 +628,14 @@ def search(ctx: click.Context, search_terms: str, limit: int, sources: Sequence[
     )
     choices = [PkgChoice(f'{p.name}  ({d.to_urn()}=={p.version})', d, pkg=p) for d, p in pkgs]
     if choices:
-        selections = checkbox('Select add-ons to install', choices=choices).unsafe_ask()
-        if selections and confirm('Install selected add-ons?').unsafe_ask():
+        selections: list[Defn] = ask(checkbox('Select add-ons to install', choices=choices))
+        if selections and ask(confirm('Install selected add-ons?')):
             ctx.invoke(install, addons=selections)
     else:
         click.echo('No results found.')
 
 
-class ListFormats(str, Enum):
+class ListFormats(StrEnum):
     simple = 'simple'
     detailed = 'detailed'
     json = 'json'
@@ -653,9 +672,11 @@ def list_installed(
             )
         )
 
-    pkgs = [
-        models.Pkg.from_row_mapping(manager.database, p)
-        for p in manager.database.execute(
+    def row_mappings_to_pkgs():
+        return map(models.Pkg.from_row_mapping, repeat(manager.database), pkg_mappings)
+
+    pkg_mappings = (
+        manager.database.execute(
             sa.select(db.pkg)
             .filter(
                 sa.or_(
@@ -674,13 +695,14 @@ def list_installed(
         )
         .mappings()
         .all()
-    ]
+    )
+
     if output_format is ListFormats.json:
-        click.echo(models.PkgList.parse_obj(pkgs).json(indent=2))
+        click.echo(models.PkgList.parse_obj(list(row_mappings_to_pkgs())).json(indent=2))
 
     elif output_format is ListFormats.detailed:
         formatter = click.HelpFormatter(max_width=99)
-        for pkg in pkgs:
+        for pkg in row_mappings_to_pkgs():
             with formatter.section(Defn.from_pkg(pkg).to_urn()):
                 formatter.write_dl(
                     [
@@ -697,7 +719,10 @@ def list_installed(
         click.echo(formatter.getvalue(), nl=False)
 
     else:
-        click.echo(''.join(f'{Defn.from_pkg(p).to_urn()}\n' for p in pkgs), nl=False)
+        click.echo(
+            ''.join(f'{Defn(p["source"], p["slug"]).to_urn()}\n' for p in pkg_mappings),
+            nl=False,
+        )
 
 
 @main.command(hidden=True)
@@ -728,11 +753,15 @@ def reveal(manager: _manager.Manager, addon: Defn) -> None:
     '--convert',
     is_flag=True,
     default=False,
-    help='Convert output to plain text.  Requires pandoc.',
+    help='Convert HTML and Markdown changelogs to plain text.  Requires pandoc.',
 )
 @ManagerWrapper.pass_manager
 def view_changelog(manager: _manager.Manager, addon: Defn | None, convert: bool) -> None:
-    "View the changelog of an installed add-on."
+    """View the changelog of an installed add-on.
+
+    If `addon` is not provided, displays the changelogs of all add-ons
+    to have been installed within one minute of the last add-on.
+    """
 
     def do_convert(source: str, changelog: str):
         import subprocess
@@ -814,18 +843,22 @@ def configure(ctx: click.Context, promptless: bool) -> Config:
     if promptless:
         make_config = Config
     else:
-        from .prompts import PydanticValidator, path, select
+        from .prompts import PydanticValidator, ask, path, select
 
-        addon_dir = path(
-            'Add-on directory:',
-            only_directories=True,
-            validate=PydanticValidator(Config, 'addon_dir'),
-        ).unsafe_ask()
-        game_flavour = select(
-            'Game flavour:',
-            choices=list(Flavour),
-            initial_choice=Config.infer_flavour(addon_dir),
-        ).unsafe_ask()
+        addon_dir = ask(
+            path(
+                'Add-on directory:',
+                only_directories=True,
+                validate=PydanticValidator(Config, 'addon_dir'),
+            )
+        )
+        game_flavour = ask(
+            select(
+                'Game flavour:',
+                choices=list(Flavour),
+                initial_choice=Config.infer_flavour(addon_dir),
+            )
+        )
         make_config = partial(Config, addon_dir=addon_dir, game_flavour=game_flavour)
 
     config = make_config(profile=ctx.find_root().params['profile']).write()
@@ -866,19 +899,19 @@ def list_installed_wago_auras(manager: _manager.Manager) -> None:
     click.echo(tabulate([('in file', 'name', 'URL'), *installed_auras]))
 
 
-def _parse_datetime(_: click.Context, __: click.Parameter, value: str | None) -> datetime | None:
-    if value is not None:
-        return datetime.fromisoformat(value)
-
-
 @main.command(hidden=True)
 @click.argument('filename', type=click.Path(dir_okay=False))
-@click.option('--age-cutoff', callback=_parse_datetime)
-def generate_catalogue(filename: str, age_cutoff: datetime | None) -> None:
+@click.option(
+    '--start-date',
+    callback=_parse_iso_date_into_datetime,
+    help='Omit results before this date.',
+    metavar='YYYY-MM-DD',
+)
+def generate_catalogue(filename: str, start_date: datetime | None) -> None:
     "Generate the master catalogue."
     from .resolvers import Catalogue
 
-    catalogue = asyncio.run(Catalogue.collate(age_cutoff))
+    catalogue = asyncio.run(Catalogue.collate(start_date))
     file = Path(filename)
     file.write_text(
         catalogue.json(indent=2),
