@@ -2,25 +2,27 @@ from __future__ import annotations
 
 import asyncio
 from collections import defaultdict
-from collections.abc import Awaitable, Callable, Iterable, Iterator, Mapping, Sequence
+from collections.abc import Awaitable, Callable, Iterable, Iterator, Mapping, Sequence, Set
 from datetime import datetime, timedelta
+import enum
 from functools import partial, wraps
-from itertools import chain, repeat, takewhile
+from itertools import chain, repeat
 import os
 from pathlib import Path, PurePath
 import posixpath
 from shutil import move as _move
 from tempfile import mkdtemp
-from typing import Generic, Hashable, TypeVar, overload
-
-from typing_extensions import TypeAlias
+from typing import Any, Generic, Hashable, TypeVar, overload
 
 from . import _deferred_types
 
 _T = TypeVar('_T')
 _U = TypeVar('_U')
 _H = TypeVar('_H', bound=Hashable)
-_StrPath: TypeAlias = 'os.PathLike[str] | str'
+
+
+class StrEnum(str, enum.Enum):
+    pass
 
 
 class TocReader:
@@ -208,9 +210,9 @@ def make_progress_bar() -> _deferred_types.prompt_toolkit.shortcuts.ProgressBar:
     return progress_bar
 
 
-def move(src: _StrPath, dest: _StrPath) -> _StrPath:
+def move(src: str | os.PathLike[str], dest: str | os.PathLike[str]) -> Any:
     return _move(
-        str(src),  # See https://bugs.python.org/issue32689
+        os.fspath(src),  # See https://bugs.python.org/issue32689
         dest,
     )
 
@@ -241,57 +243,17 @@ def is_not_stale(path: Path, ttl: Mapping[str, float]) -> bool:
     )
 
 
-async def is_outdated() -> tuple[bool, str]:
-    """Check on PyPI to see if the installed copy of instawow is outdated.
-
-    The response is cached for 24 hours.
-    """
-    from aiohttp.client import ClientError
-
-    from . import __version__
-    from .config import Config
-    from .manager import init_web_client
-
-    def parse_version(version: str) -> tuple[int, ...]:
-        version_numbers = version.split('.')[:3]
-        int_only_version_numbers = (
-            int(''.join(takewhile('0123456789'.__contains__, e))) for e in version_numbers
-        )
-        return tuple(int_only_version_numbers)
-
-    if 'dev' in __version__:
-        return (False, '')
-
-    dummy_config = Config.get_dummy_config()
-    if not dummy_config.auto_update_check:
-        return (False, '')
-
-    cache_file = dummy_config.temp_dir / '.pypi_version'
-    if await run_in_thread(is_not_stale)(cache_file, {'days': 1}):
-        version = cache_file.read_text(encoding='utf-8')
-    else:
-        try:
-            async with init_web_client(raise_for_status=True) as web_client, web_client.get(
-                'https://pypi.org/pypi/instawow/json'
-            ) as response:
-                version = (await response.json())['info']['version']
-        except ClientError:
-            version = __version__
-        else:
-            cache_file.write_text(version, encoding='utf-8')
-
-    return (parse_version(version) > parse_version(__version__), version)
-
-
-def find_zip_base_dirs(names: Sequence[str]) -> set[str]:
+def find_addon_zip_base_dirs(names: Sequence[str]) -> Iterator[str]:
     "Find top-level folders in a list of ZIP member paths."
-    return {n for n in (posixpath.dirname(n) for n in names) if n and posixpath.sep not in n}
+    for name in names:
+        if name.count(posixpath.sep) == 1:
+            head, tail = posixpath.split(name)
+            if head == tail[:-4] and tail[-4:].casefold() == '.toc':
+                yield head
 
 
-def make_zip_member_filter(base_dirs: set[str]) -> Callable[[str], bool]:
-    """Filter out items which are not sub-paths of top-level folders for the
-    purpose of extracting ZIP files.
-    """
+def make_zip_member_filter(base_dirs: Set[str]) -> Callable[[str], bool]:
+    "Filter out items which are not sub-paths of top-level folders in a ZIP."
 
     def is_subpath(name: str):
         head, sep, _ = name.partition(posixpath.sep)
