@@ -1,3 +1,4 @@
+import datetime
 from pathlib import Path
 
 from aiohttp import ClientError
@@ -6,6 +7,7 @@ import pytest
 from instawow import results as R
 from instawow.common import Strategy
 from instawow.config import Flavour
+from instawow.manager import is_outdated
 from instawow.models import Pkg
 from instawow.resolvers import Defn
 
@@ -190,27 +192,46 @@ async def test_removing_pkg_with_missing_folders(iw_manager, keep_folders):
 
 @pytest.mark.asyncio
 async def test_basic_search(iw_manager):
-    results = await iw_manager.search('molinari', limit=5)
-    defns = {Defn(e.source, e.slug or e.id) for e in results}
-    assert {Defn('curse', 'molinari'), Defn('wowi', '13188')} <= defns
+    limit = 5
+    results = await iw_manager.search('molinari', limit=limit)
+    assert len(results) == limit
+    assert {('curse', 'molinari'), ('wowi', '13188')} <= {
+        (e.source, e.slug or e.id) for e in results
+    }
+
+
+@pytest.mark.asyncio
+async def test_search_flavour_filtering(iw_manager):
+    results = await iw_manager.search('AtlasLootClassic', limit=5)
+    faux_defns = {(e.source, e.slug or e.id) for e in results}
+    if iw_manager.config.game_flavour is Flavour.vanilla_classic:
+        assert ('curse', 'atlaslootclassic') in faux_defns
+    else:
+        assert ('curse', 'atlaslootclassic') not in faux_defns
 
 
 @pytest.mark.asyncio
 async def test_search_source_filtering(iw_manager):
     results = await iw_manager.search('molinari', limit=5, sources={'curse'})
-    defns = {Defn(e.source, e.slug or e.id) for e in results}
-    assert all(d.source == 'curse' for d in defns)
-    assert {Defn('curse', 'molinari')} <= defns
+    assert all(e.source == 'curse' for e in results)
+    assert {('curse', 'molinari')} <= {(e.source, e.slug) for e in results}
 
 
 @pytest.mark.asyncio
-async def test_search_caters_to_flavour(iw_manager):
-    results = await iw_manager.search('AtlasLootClassic', limit=5)
-    defns = {Defn(e.source, e.slug or e.id) for e in results}
-    if iw_manager.config.game_flavour is Flavour.vanilla_classic:
-        assert Defn('curse', 'atlaslootclassic') in defns
-    else:
-        assert Defn('curse', 'atlaslootclassic') not in defns
+async def test_search_date_filtering(iw_manager):
+    start_date = datetime.datetime.now(tz=datetime.timezone.utc) - datetime.timedelta(days=365)
+
+    results = await iw_manager.search('molinari', limit=5)
+    assert any(e.last_updated < start_date for e in results)
+
+    results = await iw_manager.search('molinari', limit=5, start_date=start_date)
+    assert all(e.last_updated > start_date for e in results)
+
+
+@pytest.mark.asyncio
+async def test_search_unknown_source(iw_manager):
+    with pytest.raises(ValueError, match='Unknown source'):
+        await iw_manager.search('molinari', limit=5, sources={'foo'})
 
 
 @pytest.mark.asyncio
@@ -235,13 +256,96 @@ async def test_get_changelog_from_file_uri(iw_manager):
         await iw_manager.get_changelog(
             (Path(__file__).parent / 'fixtures' / 'curse-addon-changelog.txt').as_uri()
         )
-    ).startswith('<h3>Changes in 90000.73-Release:</h3>')
+    ).startswith('<h3>Changes in 90100.79-Release:</h3>')
 
 
 @pytest.mark.asyncio
 async def test_get_changelog_from_web_url(iw_manager):
     assert (
         await iw_manager.get_changelog(
-            'https://addons-ecs.forgesvc.net/api/v2/addon/20338/file/3152268/changelog'
+            'https://addons-ecs.forgesvc.net/api/v2/addon/20338/file/3475338/changelog'
         )
-    ).startswith('<h3>Changes in 90000.73-Release:</h3>')
+    ).startswith('<h3>Changes in 90100.79-Release:</h3>')
+
+
+@pytest.mark.iw_no_mock
+@pytest.mark.asyncio
+async def test_is_outdated_works_in_variety_of_scenarios(monkeypatch, aresponses, iw_temp_dir):
+    pypi_version = iw_temp_dir.joinpath('.pypi_version')
+    if pypi_version.exists():
+        pypi_version.unlink()
+
+    # version == '0.0.0', version not cached
+    with monkeypatch.context() as patcher:
+        patcher.setattr('instawow.__version__', '0.0.0')
+        assert await is_outdated() == (False, '')
+
+    # Update check disabled, version not cached
+    with monkeypatch.context() as patcher:
+        patcher.setenv('INSTAWOW_AUTO_UPDATE_CHECK', '0')
+        assert await is_outdated() == (False, '')
+
+    # Endpoint not responsive, version not cached
+    with monkeypatch.context() as patcher:
+        patcher.setattr('instawow.__version__', '0.1.0')
+        aresponses.add(
+            'pypi.org',
+            '/pypi/instawow/json',
+            'get',
+            aresponses.Response(status=500),
+        )
+        assert await is_outdated() == (False, '0.1.0')
+
+    # Endpoint responsive, version not cached and version different
+    with monkeypatch.context() as patcher:
+        patcher.setattr('instawow.__version__', '0.1.0')
+        aresponses.add(
+            'pypi.org',
+            '/pypi/instawow/json',
+            'get',
+            {'info': {'version': '1.0.0'}},
+        )
+        assert await is_outdated() == (True, '1.0.0')
+
+    # version == '0.0.0', version cached
+    with monkeypatch.context() as patcher:
+        patcher.setattr('instawow.__version__', '0.0.0')
+        assert await is_outdated() == (False, '')
+
+    # Update check disabled, version cached
+    with monkeypatch.context() as patcher:
+        patcher.setenv('INSTAWOW_AUTO_UPDATE_CHECK', '0')
+        assert await is_outdated() == (False, '')
+
+    # Endpoint not responsive, version cached
+    with monkeypatch.context() as patcher:
+        patcher.setattr('instawow.__version__', '0.1.0')
+        aresponses.add(
+            'pypi.org',
+            '/pypi/instawow/json',
+            'get',
+            aresponses.Response(status=500),
+        )
+        assert await is_outdated() == (True, '1.0.0')
+
+    # Endpoint responsive, version cached and version same
+    with monkeypatch.context() as patcher:
+        patcher.setattr('instawow.__version__', '0.1.0')
+        aresponses.add(
+            'pypi.org',
+            '/pypi/instawow/json',
+            'get',
+            {'info': {'version': '1.0.0'}},
+        )
+        assert await is_outdated() == (True, '1.0.0')
+
+    # Endpoint responsive, version cached and version different
+    with monkeypatch.context() as patcher:
+        patcher.setattr('instawow.__version__', '1.0.0')
+        aresponses.add(
+            'pypi.org',
+            '/pypi/instawow/json',
+            'get',
+            {'info': {'version': '1.0.0'}},
+        )
+        assert await is_outdated() == (False, '1.0.0')
