@@ -1,16 +1,18 @@
+from __future__ import annotations
+
 import asyncio
+from itertools import product
 from pathlib import Path
 import sys
 import time
 
 import pytest
 
-from instawow.manager import find_zip_base_dirs, make_zip_member_filter
+from instawow.manager import find_addon_zip_base_dirs, make_zip_member_filter
 from instawow.utils import (
     TocReader,
     bucketise,
     file_uri_to_path,
-    is_outdated,
     merge_intersecting_sets,
     run_in_thread,
     tabulate,
@@ -22,21 +24,30 @@ def fake_addon():
     yield Path(__file__).parent / 'fixtures' / 'FakeAddon'
 
 
-def test_find_zip_base_dirs_can_find_explicit_dirs():
-    assert find_zip_base_dirs(['b/', 'b/b.toc']) == {'b'}
+def test_find_addon_zip_base_dirs_can_find_explicit_dirs():
+    assert set(find_addon_zip_base_dirs(['b/', 'b/b.toc'])) == {'b'}
 
 
-def test_find_zip_base_dirs_can_find_implicit_dirs():
-    assert find_zip_base_dirs(['b/b.toc']) == {'b'}
+def test_find_addon_zip_base_dirs_can_find_implicit_dirs():
+    assert set(find_addon_zip_base_dirs(['b/b.toc'])) == {'b'}
 
 
-def test_find_zip_base_dirs_discards_files_in_root():
-    assert find_zip_base_dirs(['a', 'b/b.toc', 'c/']) == {'b', 'c'}
+def test_find_addon_zip_base_dirs_discards_tocless_paths():
+    assert set(find_addon_zip_base_dirs(['a', 'b/b.toc', 'c/'])) == {'b'}
+
+
+def test_find_addon_zip_base_dirs_discards_mismatched_tocs():
+    assert not set(find_addon_zip_base_dirs(['a', 'a/b.toc']))
+
+
+@pytest.mark.parametrize('ext', product('Tt', 'Oo', 'Cc'))
+def test_find_addon_zip_base_dirs_toc_is_case_insensitive(ext: tuple[str, ...]):
+    assert set(find_addon_zip_base_dirs([f'a/a.{"".join(ext)}'])) == {'a'}
 
 
 def test_make_zip_member_filter_discards_names_with_prefix_not_in_dirs():
     is_member = make_zip_member_filter({'b'})
-    assert list(map(is_member, ['a/', 'b/', 'aa/', 'bb/'])) == [False, True, False, False]
+    assert list(filter(is_member, ['a/', 'b/', 'aa/', 'bb/', 'b/c', 'a/d'])) == ['b/', 'b/c']
 
 
 def test_loading_toc_from_addon_path(fake_addon):
@@ -117,89 +128,6 @@ def test_file_uri_to_path_win32_leading_slash_is_stripped():
     assert file_uri_to_path(uri) == 'C:/foo/bar'
 
 
-@pytest.mark.iw_no_mock
-@pytest.mark.asyncio
-async def test_is_outdated_works_in_variety_of_scenarios(monkeypatch, aresponses, iw_temp_dir):
-    pypi_version = iw_temp_dir.joinpath('.pypi_version')
-    if pypi_version.exists():
-        pypi_version.unlink()
-
-    # 'dev' in version number, version not cached
-    with monkeypatch.context() as patcher:
-        patcher.setattr('instawow.__version__', '0.0.0-dev')
-        assert await is_outdated() == (False, '')
-
-    # Update check disabled, version not cached
-    with monkeypatch.context() as patcher:
-        patcher.setenv('INSTAWOW_AUTO_UPDATE_CHECK', '0')
-        assert await is_outdated() == (False, '')
-
-    # Endpoint not responsive, version not cached
-    with monkeypatch.context() as patcher:
-        patcher.setattr('instawow.__version__', '0.0.0')
-        aresponses.add(
-            'pypi.org',
-            '/pypi/instawow/json',
-            'get',
-            aresponses.Response(status=500),
-        )
-        assert await is_outdated() == (False, '0.0.0')
-
-    # Endpoint responsive, version not cached and version different
-    with monkeypatch.context() as patcher:
-        patcher.setattr('instawow.__version__', '0.0.0')
-        aresponses.add(
-            'pypi.org',
-            '/pypi/instawow/json',
-            'get',
-            {'info': {'version': '1.0.0'}},
-        )
-        assert await is_outdated() == (True, '1.0.0')
-
-    # 'dev' in version number, version cached
-    with monkeypatch.context() as patcher:
-        patcher.setattr('instawow.__version__', '0.0.0-dev')
-        assert await is_outdated() == (False, '')
-
-    # Update check disabled, version cached
-    with monkeypatch.context() as patcher:
-        patcher.setenv('INSTAWOW_AUTO_UPDATE_CHECK', '0')
-        assert await is_outdated() == (False, '')
-
-    # Endpoint not responsive, version cached
-    with monkeypatch.context() as patcher:
-        patcher.setattr('instawow.__version__', '0.0.0')
-        aresponses.add(
-            'pypi.org',
-            '/pypi/instawow/json',
-            'get',
-            aresponses.Response(status=500),
-        )
-        assert await is_outdated() == (True, '1.0.0')
-
-    # Endpoint responsive, version cached and version same
-    with monkeypatch.context() as patcher:
-        patcher.setattr('instawow.__version__', '0.0.0')
-        aresponses.add(
-            'pypi.org',
-            '/pypi/instawow/json',
-            'get',
-            {'info': {'version': '1.0.0'}},
-        )
-        assert await is_outdated() == (True, '1.0.0')
-
-    # Endpoint responsive, version cached and version different
-    with monkeypatch.context() as patcher:
-        patcher.setattr('instawow.__version__', '1.0.0')
-        aresponses.add(
-            'pypi.org',
-            '/pypi/instawow/json',
-            'get',
-            {'info': {'version': '1.0.0'}},
-        )
-        assert await is_outdated() == (False, '1.0.0')
-
-
 @pytest.mark.asyncio
 async def test_generator_in_run_in_thread_does_not_lock_up_loop():
     def foo():
